@@ -1,7 +1,7 @@
 #!/bin/bash
 
 trap "exit 130" INT
-cleanup() { rm -f test.ini good.ini example.ini; exit; }
+cleanup() { rm -f err noequals*.ini test.ini ltest.ini good.ini example.ini; exit; }
 trap cleanup EXIT
 
 export PATH=..:$PATH
@@ -217,6 +217,13 @@ printf '%s\n' '#comment' '[section1]' > test.ini
 test "$(crudini --get test.ini)" = 'section1' || fail
 ok
 
+# Ensure we handle comments correctly
+printf '%s\n' '[DEFAULT]' '#c1' ';c2' '%inc1' > test.ini
+test "$(crudini --get test.ini)" = '' || fail
+printf '%s\n' '[section1]' 'remote=1' > test.ini
+test "$(crudini --get test.ini 'section1')" = 'remote' || fail
+ok
+
 # missing bits
 :> test.ini
 crudini --get missing.ini 2>/dev/null && fail
@@ -465,3 +472,34 @@ printf '%s\n' '' 'option=2' > good.conf
 crudini --set file.conf '' option 2 || fail
 diff -u good.conf file.conf && ok || fail
 rm file.conf good.conf
+
+# ensure errors diagnosed correctly
+crudini --get example.ini 2>err | :
+! test -s err && ok || fail  #EPIPE ignored
+if test -e /dev/full; then
+crudini --get example.ini 2>err >/dev/full
+grep -q 'No space left' err && ok || fail
+fi
+
+# ensure symlinks handled correctly in file replace mode
+printf '%s\n' '[section]' 'param = value' > test.ini
+ln -s test.ini ltest.ini
+crudini --set ltest.ini section param newvalue || fail
+test "$(crudini --get test.ini section param)" = 'newvalue' && ok || fail
+crudini --output=ltest.ini --set ltest.ini section param newvalue2 || fail
+test "$(crudini --get test.ini section param)" = 'newvalue2' && ok || fail
+
+# Test single token parameters (without equals)
+cp ../noequals.ini .
+crudini --get noequals.ini >/dev/null && ok || fail
+cp noequals.ini noequals_new.ini
+printf '%s\n' 'new' 'new_equals = ' >> noequals_new.ini
+for param in param{1..3} colon{1..2} new; do
+ crudini --set noequals.ini noequals $param || fail
+done
+crudini --set noequals.ini noequals new_equals '' || fail
+diff -u noequals.ini noequals_new.ini && ok || fail
+
+# Test can read windows format files
+printf '%s\r\n' '' 'param = value' > test.ini
+crudini --get test.ini DEFAULT param > /dev/null || fail
